pub struct ZwpTabletManagerV2 { /* private fields */ }Expand description
controller object for graphic tablet devices
An object that provides access to the graphics tablets available on this system. All tablets are associated with a seat, to get access to the actual tablets, use zwp_tablet_manager_v2.get_tablet_seat.
See also the Request enum for this interface.